@@ -48,13 +48,13 @@ public:
     /**
      * Destructor
      */
-    virtual ~SimpleActionDataWidget();
+    ~SimpleActionDataWidget() override;
 
-    bool isChanged() const Q_DECL_OVERRIDE;
+    bool isChanged() const override;
 
 protected:
-    void doCopyFromObject() Q_DECL_OVERRIDE;
-    void doCopyToObject() Q_DECL_OVERRIDE;
+    void doCopyFromObject() override;
+    void doCopyToObject() override;
 
 private:
     HotkeysWidgetIFace *currentTrigger;
